Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(17)

Unified Diff: ui/views/window/frame_background.h

Issue 10447053: Converts remainder of ui and chrome/browser/ui/views/frame to use ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/window/custom_frame_view.cc ('k') | ui/views/window/frame_background.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/window/frame_background.h
diff --git a/ui/views/window/frame_background.h b/ui/views/window/frame_background.h
index e68ff27fdbf09897e1e57bcb082308d3598da5ef..4b0d3907c0b7b10fc8c5ab04a11faa79d95bd73f 100644
--- a/ui/views/window/frame_background.h
+++ b/ui/views/window/frame_background.h
@@ -10,9 +10,9 @@
#include "third_party/skia/include/core/SkColor.h"
#include "ui/views/views_export.h"
-class SkBitmap;
namespace gfx {
class Canvas;
+class ImageSkia;
}
namespace views {
@@ -27,18 +27,18 @@ class VIEWS_EXPORT FrameBackground {
FrameBackground();
~FrameBackground();
- // Sets the color to draw under the frame bitmaps.
+ // Sets the color to draw under the frame images.
void set_frame_color(SkColor color) { frame_color_ = color; }
// Sets the theme bitmap for the top of the window. May be NULL.
// Memory is owned by the caller.
- void set_theme_bitmap(const SkBitmap* bitmap) { theme_bitmap_ = bitmap; }
+ void set_theme_image(const gfx::ImageSkia* image) { theme_image_ = image; }
- // Sets an image that overlays the top window bitmap. Usually used to add
+ // Sets an image that overlays the top window image. Usually used to add
// edge highlighting to provide the illusion of depth. May be NULL.
// Memory is owned by the caller.
- void set_theme_overlay_bitmap(SkBitmap* bitmap) {
- theme_overlay_bitmap_ = bitmap;
+ void set_theme_overlay_image(gfx::ImageSkia* image) {
+ theme_overlay_image_ = image;
}
// Sets the height of the top area to fill with the default frame color,
@@ -53,17 +53,17 @@ class VIEWS_EXPORT FrameBackground {
// Sets images used when drawing the sides of the frame.
// Caller owns the memory.
- void SetSideImages(const SkBitmap* left,
- const SkBitmap* top,
- const SkBitmap* right,
- const SkBitmap* bottom);
+ void SetSideImages(const gfx::ImageSkia* left,
+ const gfx::ImageSkia* top,
+ const gfx::ImageSkia* right,
+ const gfx::ImageSkia* bottom);
// Sets images used when drawing the corners of the frame.
// Caller owns the memory.
- void SetCornerImages(const SkBitmap* top_left,
- const SkBitmap* top_right,
- const SkBitmap* bottom_left,
- const SkBitmap* bottom_right);
+ void SetCornerImages(const gfx::ImageSkia* top_left,
+ const gfx::ImageSkia* top_right,
+ const gfx::ImageSkia* bottom_left,
+ const gfx::ImageSkia* bottom_right);
// Paints the border for a standard, non-maximized window. Also paints the
// background of the title bar area, since the top frame border and the
@@ -79,26 +79,26 @@ class VIEWS_EXPORT FrameBackground {
void PaintFrameColor(gfx::Canvas* canvas, View* view) const;
SkColor frame_color_;
- const SkBitmap* theme_bitmap_;
- SkBitmap* theme_overlay_bitmap_;
+ const gfx::ImageSkia* theme_image_;
+ gfx::ImageSkia* theme_overlay_image_;
int top_area_height_;
// Images for the sides of the frame.
- const SkBitmap* left_edge_;
- const SkBitmap* top_edge_;
- const SkBitmap* right_edge_;
- const SkBitmap* bottom_edge_;
+ const gfx::ImageSkia* left_edge_;
+ const gfx::ImageSkia* top_edge_;
+ const gfx::ImageSkia* right_edge_;
+ const gfx::ImageSkia* bottom_edge_;
// Images for the corners of the frame.
- const SkBitmap* top_left_corner_;
- const SkBitmap* top_right_corner_;
- const SkBitmap* bottom_left_corner_;
- const SkBitmap* bottom_right_corner_;
+ const gfx::ImageSkia* top_left_corner_;
+ const gfx::ImageSkia* top_right_corner_;
+ const gfx::ImageSkia* bottom_left_corner_;
+ const gfx::ImageSkia* bottom_right_corner_;
// Attributes for maximized window painting.
// TODO(jamescook): Remove all these.
- SkBitmap* maximized_top_left_;
- SkBitmap* maximized_top_right_;
+ gfx::ImageSkia* maximized_top_left_;
+ gfx::ImageSkia* maximized_top_right_;
int maximized_top_offset_;
int theme_background_y_;
« no previous file with comments | « ui/views/window/custom_frame_view.cc ('k') | ui/views/window/frame_background.cc » ('j') | no next file with comments »
@@ -27,18 +27,18 @@ class VIEWS_EXPORT FrameBackground {
void set_frame_color(SkColor color) { frame_color_ = color; }
- // Sets the theme bitmap for the top of the window. May be NULL.
+ // Sets the theme image for the top of the window. May be NULL.
// Memory is owned by the caller.

Powered by Google App Engine
This is Rietveld 408576698